import 'package:ez_localization/ez_localization.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easy_utils/flutter_easy_utils.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:new_version/new_version.dart';
import 'package:rflutter_alert/rflutter_alert.dart';
import 'package:shared_preferences/shared_preferences.dart';

errorAlert(context, error, {Function fun, errorKey: "error", okKey: "ok"}) {
  Alert(
      type: AlertType.error,
      context: context,
      desc: error,
      title: tran(context, errorKey),
      buttons: [
        DialogButton(
            child: Text(tran(context, okKey)),
            onPressed: () {
              Navigator.pop(context);
              if (fun != null) {
                fun();
              }
            })
      ]).show();
}

successAlert(context,
    {message,
    Function fun,
    doneKey: "done",
    successKey: "success",
    okKey: "ok"}) {
  Alert(
      type: AlertType.success,
      context: context,
      desc: message == null ? tran(context, doneKey) : message,
      title: tran(context, successKey),
      buttons: [
        DialogButton(
            child: Text(tran(context, okKey)),
            onPressed: () {
              Navigator.pop(context);
              if (fun != null) {
                fun();
              }
            })
      ]).show();
}

heartDialog(context) {
  return showDialog(
    context: context,
    barrierDismissible: false,
    builder: (dialogContext) {
      return Directionality(
        child: SpinKitPumpingHeart(
          color: Colors.pink,
        ),
        textDirection: TextDirection.ltr,
      );
    },
  );
}

noInternetDialog(context, {noInternetKey: "no_internet"}) {
  return showDialog(
    context: context,
    barrierColor: Colors.white,
    barrierDismissible: false,
    builder: (context) => Column(
      crossAxisAlignment: CrossAxisAlignment.center,
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Directionality(
          child: SpinKitFoldingCube(
            color: Theme.of(context).primaryColor,
          ),
          textDirection: TextDirection.ltr,
        ),
        SizedBox(
          height: 30,
        ),
        Text(
          tran(context, noInternetKey),
          textAlign: TextAlign.center,
          style: TextStyle(
            fontSize: 20,
            color: Theme.of(context).primaryColor,
          ),
        ),
      ],
    ),
  );
}

confirmAge(context,
    {confirmKey: "confirm",
    yesKey: "yes",
    noKey: "no",
    areYou18Key: "are_you_18"}) async {
  SharedPreferences prefs = await SharedPreferences.getInstance();
  bool _ageConfirmed = prefs.getBool('ageConfirmed') ?? false;
  if (!_ageConfirmed) {
    Alert(
        type: AlertType.warning,
        context: context,
        title: tran(context, confirmKey),
        desc: tran(context, areYou18Key),
        buttons: [
          DialogButton(
              color: Colors.red,
              child: Text(tran(context, yesKey)),
              onPressed: () {
                Navigator.pop(context);
                prefs.setBool('ageConfirmed', true);
              }),
          DialogButton(
              color: Colors.green,
              child: Text(tran(context, noKey)),
              onPressed: () {
                Navigator.pop(context);
                SystemNavigator.pop(animated: true);
              }),
        ]).show();
  }
}

snackBar(context, message, {AlertType type: AlertType.info}) {
  final ScaffoldMessengerState scaffoldMessenger =
      ScaffoldMessenger.of(context);
  scaffoldMessenger.showSnackBar(
    SnackBar(
      duration: Duration(seconds: 2),
      content: Text(message),
      padding: EdgeInsets.symmetric(vertical: 5, horizontal: 20),
      backgroundColor: type == AlertType.error
          ? Colors.redAccent
          : type == AlertType.success
              ? Colors.greenAccent
              : type == AlertType.info
                  ? Colors.blueAccent
                  : type == AlertType.warning
                      ? Colors.orangeAccent
                      : Colors.black,
    ),
  );
}

///
checkVersion(context) async {
  final newVersion = NewVersion();

  var status = await newVersion.getVersionStatus();

  if (status != null && status.canUpdate) {
    Alert(
        type: AlertType.info,
        context: context,
        title: EzLocalization.of(context).get("update"),
        desc: EzLocalization.of(context).get("update_your_app",
            {"from": status.localVersion, "to": status.storeVersion}),
        buttons: []).show();
  }
}
